==> kde4libs_3.80.3.orig.tar.gz: kde4libs-3.80.3/kdeui/kernel/kclipboard.h <==
/* This file is part of the KDE libraries
    Copyright (C) 2002 Carsten Pfeiffer <pfeiffer@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2, as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef KCLIPBOARD_H
#define KCLIPBOARD_H

#include <qobject.h>
#include <qclipboard.h>
#include <kdelibs_export.h>

template <class T> class KStaticDeleter;
class QMimeData;

/**
 * This class is only for internal use.
 *
 * @short Allowing to automatically synchronize the X11 Clipboard and Selection buffers.
 * @author Carsten Pfeiffer <pfeiffer@kde.org>
 */
class KDEUI_EXPORT KClipboardSynchronizer : public QObject
{
    Q_OBJECT

public:
    friend class KlipperWidget;

    /**
     * Returns the KClipboardSynchronizer singleton object.
     * @return the KClipboardSynchronizer singleton object.
     */
    static KClipboardSynchronizer *self();

    /**
     * Configures KClipboardSynchronizer to synchronize the Selection to Clipboard whenever
     * it changes.
     *
     * Default is false.
     * @see isSynchronizing
     */
    static void setSynchronizing( bool sync );

    /**
     * Checks whether Clipboard and Selection will be synchronized upon changes.
     * @returns whether Clipboard and Selection will be synchronized upon
     * changes.
     * @see setSynchronizing
     */
    static bool isSynchronizing()
    {
        return s_sync;
    }

    /**
     * Configures KClipboardSynchronizer to copy the Clipboard buffer to the Selection
     * buffer whenever the Clipboard changes.
     *
     *
     * @param enable true to enable implicit selection, false otherwise.
     * Default is true.
     * @see selectionSetting
     */
    static void setReverseSynchronizing( bool enable );

    /**
     * Checks whether the  Clipboard buffer will be copied to the Selection
     * buffer upon changes.
     * @returns whether the Clipboard buffer will be copied to the Selection
     * buffer upon changes.
     * @see setSelectionSetting
     */
    static bool isReverseSynchronizing()
    {
        return s_reverse_sync;
    }


protected:
    friend class KStaticDeleter<KClipboardSynchronizer>;
    ~KClipboardSynchronizer();

private Q_SLOTS:
    void slotSelectionChanged();
    void slotClipboardChanged();
    void slotNotifyChange(int, int);

private:
    explicit KClipboardSynchronizer( QObject *parent = 0 );
    void setupSignals();

    static void setClipboard( const QMimeData* data, QClipboard::Mode mode );

    static KClipboardSynchronizer *s_self;
    static bool s_sync;
    static bool s_reverse_sync;
    static bool s_blocked;

private:
    // needed by klipper
    enum Configuration { Synchronize = 1 };
};

#endif // KCLIPBOARD_H

==> kde4libs_3.93.0.orig.tar.gz: kde4libs-3.93.0.orig/kdeui/kernel/kclipboard.h <==
/* This file is part of the KDE libraries
    Copyright (C) 2002 Carsten Pfeiffer <pfeiffer@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2, as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef KCLIPBOARD_H
#define KCLIPBOARD_H

#include <kdeui_export.h>

#include <QtCore/QObject>
#include <QtGui/QClipboard>

class QMimeData;

/**
 * This class is only for internal use.
 *
 * @short Allowing to automatically synchronize the X11 Clipboard and Selection buffers.
 * @author Carsten Pfeiffer <pfeiffer@kde.org>
 */
class KDEUI_EXPORT KClipboardSynchronizer : public QObject
{
    Q_OBJECT

public:
    friend class KlipperWidget;

    /**
     * Returns the KClipboardSynchronizer singleton object.
     * @return the KClipboardSynchronizer singleton object.
     */
    static KClipboardSynchronizer *self();

    /**
     * Configures KClipboardSynchronizer to synchronize the Selection to Clipboard whenever
     * it changes.
     *
     * Default is false.
     * @see isSynchronizing
     */
    static void setSynchronizing( bool sync );

    /**
     * Checks whether Clipboard and Selection will be synchronized upon changes.
     * @returns whether Clipboard and Selection will be synchronized upon
     * changes.
     * @see setSynchronizing
     */
    static bool isSynchronizing()
    {
        return s_sync;
    }

    /**
     * Configures KClipboardSynchronizer to copy the Clipboard buffer to the Selection
     * buffer whenever the Clipboard changes.
     *
     *
     * @param enable true to enable implicit selection, false otherwise.
     * Default is true.
     * @see selectionSetting
     */
    static void setReverseSynchronizing( bool enable );

    /**
     * Checks whether the  Clipboard buffer will be copied to the Selection
     * buffer upon changes.
     * @returns whether the Clipboard buffer will be copied to the Selection
     * buffer upon changes.
     * @see setSelectionSetting
     */
    static bool isReverseSynchronizing()
    {
        return s_reverse_sync;
    }


protected:
    ~KClipboardSynchronizer();

private Q_SLOTS:
    void slotSelectionChanged();
    void slotClipboardChanged();
    void slotNotifyChange(int, int);

private:
    explicit KClipboardSynchronizer( QObject *parent = 0 );
    void setupSignals();

    static void setClipboard( const QMimeData* data, QClipboard::Mode mode );

    static bool s_sync;
    static bool s_reverse_sync;
    static bool s_blocked;

private:
    // needed by klipper
    enum Configuration { Synchronize = 1 };
};

#endif // KCLIPBOARD_H
